@@ -230,6 +230,7 @@ path_equal (const char *a, const char *b, gboolean relax)
 {
   gboolean res;
   size_t a_len, b_len;
+  char *ua, *ub;
 
   if (relax == FALSE)
     return str_equal (a, b, FALSE);
@@ -237,20 +238,26 @@ path_equal (const char *a, const char *b, gboolean relax)
   if (a == NULL || b == NULL)
       return a == b;
 
-  a_len = strlen (a);
-  b_len = strlen (b);
+  ua = g_uri_unescape_string (a, "/");
+  ub = g_uri_unescape_string (b, "/");
 
-  while (a_len > 0 && a[a_len - 1] == '/')
+  a_len = strlen (ua);
+  b_len = strlen (ub);
+
+  while (a_len > 0 && ua[a_len - 1] == '/')
     a_len--;
 
-  while (b_len > 0 && b[b_len - 1] == '/')
+  while (b_len > 0 && ub[b_len - 1] == '/')
     b_len--;
 
   if (a_len == b_len)
-    res = ! strncmp (a, b, a_len);
+    res = ! strncmp (ua, ub, a_len);
   else
     res = FALSE;
 
+  g_free(ua);
+  g_free(ub);
+
   return res;
 }
 
@@ -259,20 +266,13 @@ static gboolean
 dav_uri_match (SoupURI *a, SoupURI *b, gboolean relax)
 {
   gboolean diff;
-  char *ua, *ub;
-
-  ua = g_uri_unescape_string (a->path, "/");
-  ub = g_uri_unescape_string (b->path, "/");
 
   diff = a->scheme != b->scheme || a->port != b->port  ||
     ! str_equal (a->host, b->host, TRUE)               ||
-    ! path_equal (ua, ub, relax)                       ||
+    ! path_equal (a->path, b->path, relax)             ||
     ! str_equal (a->query, b->query, FALSE)            ||
     ! str_equal (a->fragment, b->fragment, FALSE);
 
-  g_free (ua);
-  g_free (ub);
-
   return !diff;
 }
 
@@ -2304,7 +2304,7 @@ try_create_tested_existence (SoupSession *session, SoupMessage *msg,
    * Doesn't work with apache > 2.2.9
    * soup_message_headers_append (put_msg->request_headers, "If-None-Match", "*");
    */
-  stream = g_memory_output_stream_new (NULL, 0, g_realloc, g_free);
+  stream = g_memory_output_stream_new (NULL, 0, g_try_realloc, g_free);
   g_object_set_data_full (G_OBJECT (stream), "-gvfs-stream-msg", put_msg, g_object_unref);
 
   g_vfs_job_open_for_write_set_handle (G_VFS_JOB_OPEN_FOR_WRITE (job), stream);
@@ -2350,7 +2350,7 @@ open_for_replace_succeeded (GVfsBackendHttp *op_backend, GVfsJob *job,
   if (etag)
     soup_message_headers_append (put_msg->request_headers, "If-Match", etag);
 
-  stream = g_memory_output_stream_new (NULL, 0, g_realloc, g_free);
+  stream = g_memory_output_stream_new (NULL, 0, g_try_realloc, g_free);
   g_object_set_data_full (G_OBJECT (stream), "-gvfs-stream-msg", put_msg, g_object_unref);
 
   g_vfs_job_open_for_write_set_handle (G_VFS_JOB_OPEN_FOR_WRITE (job), stream);
@@ -2725,10 +2725,23 @@ do_move (GVfsBackend *backend,
 
   if (flags & G_FILE_COPY_BACKUP)
     {
-      g_vfs_job_failed_literal (G_VFS_JOB(job),
-                                G_IO_ERROR,
-                                G_IO_ERROR_CANT_CREATE_BACKUP,
-                                _("Backup file creation failed"));
+      if (flags & G_FILE_COPY_NO_FALLBACK_FOR_MOVE)
+        {
+          g_vfs_job_failed_literal (G_VFS_JOB (job),
+                                    G_IO_ERROR,
+                                    G_IO_ERROR_CANT_CREATE_BACKUP,
+                                    _("Backups not supported"));
+        }
+      else
+        {
+          /* Return G_IO_ERROR_NOT_SUPPORTED instead of G_IO_ERROR_CANT_CREATE_BACKUP
+           * to be proceeded with copy and delete fallback (see g_file_move). */
+          g_vfs_job_failed_literal (G_VFS_JOB (job),
+                                    G_IO_ERROR,
+                                    G_IO_ERROR_NOT_SUPPORTED,
+                                    "Operation not supported");
+        }
+
       return;
     }
 
